<?php
$lang['error_insufficientparams'] = 'Faltan los par&aacute;metros necesarios';
$lang['error_duplicatename'] = 'Ya existe un &iacute;tem con el mismo nombre';
$lang['detail_page'] = 'P&aacute;gina de detalle';
$lang['detail_template'] = 'Plantilla de detalle';
$lang['warning_preview'] = 'Aviso: Este panel de vista previa se comporta de forma muy parecida a la ventana de un navegador permiti&eacute;ndole navegar fuera de la p&aacute;gina previsualizada inicialmente. Si navega fuera de la p&aacute;gina inicial, cuando regrese puede no obtener los resultados esperados<br/><strong>Nota:</strong> La vista previa no sube los archivos que seleccione para subir.';
$lang['article'] = 'Art&iacute;culo';
$lang['preview'] = 'Vista previa';
$lang['info_detail_returnid'] = 'Esta preferencia se usa para determinar una p&aacute;gina (y por lo tanto una plantilla) en la que mostrar la vista de detalle. Las URLs individualizadas para los detalles de las Noticias no funcionar&aacute;n a menos que este par&aacute;metro se configure con una p&aacute;gina valida. Adicionalmente, si esta preferencia est&aacute; establecida, y no se proporciona el parametro &#039;detailpage&#039; (p&aacute;gina de detalle) en la etiqueta de noticias, entonces este valor ser&aacute; utilizado para los enlaces de detalle';
$lang['title_detail_returnid'] = 'P&aacute;gina por defecto para las vistas de detalle';
$lang['title_submission_settings'] = 'Configuraci&oacute;n de env&iacute;o de Noticias';
$lang['title_fesubmit_settings'] = 'Configuraci&oacute;n de env&iacute;o a trav&eacute;s del portal';
$lang['title_notification_settings'] = 'Configuraci&oacute;n de notificaci&oacute;n';
$lang['title_detail_settings'] = 'Configuraci&oacute;n de la vista de detalle';
$lang['error_invalidurl'] = 'URL Inv&aacute;lida <em>(puede que est&eacute; en uso, o que contenga caracteres inv&aacute;lidos)</em>';
$lang['url'] = 'URL ';
$lang['expired_searchable'] = 'Los art&iacute;culos vencidos pueden aparecer en resultados de b&uacute;squedas';
$lang['helpshowall'] = 'Mostrar todos los art&iacute;culos, sin importar la fecha en que finalizan';
$lang['error_invaliddates'] = 'Una o m&aacute;s de las fechas introducidas son invalidas';
$lang['notify_n_draft_items_sub'] = 'Art&iacute;culo(s) de Noticias s%';
$lang['notify_n_draft_items'] = 'Tiene %s que no han sido publicados';
$lang['unlimited'] = 'Ilimitado';
$lang['none'] = 'Ninguno';
$lang['anonymous'] = 'An&oacute;nimo';
$lang['unknown'] = 'Desconocido';
$lang['fesubmit_redirect'] = 'El ID o Alias de la p&aacute;gina a donde se redireccionar&aacute; despu&eacute;s de que un art&iacute;culo de noticias ha sido enviado a trav&eacute;s de la acci&oacute;n FEsubmit';
$lang['allow_summary_wysiwyg'] = 'Permitir el uso del Editor WYSIWYG en el campo resumen';
$lang['title_browsecat_template'] = 'Editor de la Plantilla de Navegaci&oacute;n por Categor&iacute;as';
$lang['title_browsecat_sysdefault'] = 'Plantilla por Defecto de Navegaci&oacute;n por Categor&iacute;as';
$lang['browsecattemplate'] = 'Plantillas de Navegaci&oacute;n por Categor&iacute;as';
$lang['error_filesize'] = 'Se ha subido un archivo que excede el tama&ntilde;o m&aacute;ximo permitido';
$lang['post_date_desc'] = 'Fecha Entrada Descendente';
$lang['post_date_asc'] = 'Fecha Entrada Ascendente';
$lang['expiry_date_desc'] = 'Fecha Vence Descendente';
$lang['expiry_date_asc'] = 'Fecha Vence Ascendente';
$lang['title_desc'] = 'T&iacute;tulo Descendente';
$lang['title_asc'] = 'T&iacute;tulo Ascendente';
$lang['status_desc'] = 'Status Descendiente';
$lang['status_asc'] = 'Stado Ascendente';
$lang['fesubmit_status'] = 'El estado de art&iacute;culos de noticias enviados v&iacute;a el portal';
$lang['error_invalidfiletype'] = 'No se puede subir este tipo de archivo';
$lang['error_upload'] = 'Ha ocurrido un problema al subir un archivo';
$lang['error_movefile'] = 'No se pudo crear el archivo: %s';
$lang['error_mkdir'] = 'No se pudo crear el directorio: %s';
$lang['expiry_interval'] = 'El n&uacute;mero de d&iacute;as (por defecto) antes que un art&iacute;culo haya vencido (si se elige vencer)';
$lang['removed'] = 'Quitado';
$lang['msg_contenttype_removed'] = 'El tipo de contenido de noticias se ha quitado.  Sit&uacute;e los tags {news} con los par&aacute;metros apropiados en la plantilla de la p&aacute;gina o en el contenido de la p&aacute;gina para reemplazar esta funcionalidad.';
$lang['delete_selected'] = 'Eliminar los art&iacute;culos elegidos';
$lang['areyousure_deletemultiple'] = '&iquest;Est&aacute; seguro que quiere eliminar a todos estos art&iacute;culos de noticias?\n&iexcl;Esta acci&oacute;n es irrecuperable!';
$lang['error_templatenamexists'] = 'Ya existe una plantilla con ese nombre';
$lang['error_noarticlesselected'] = 'No se ha elegido ning&uacute;n art&iacute;culo';
$lang['reassign_category'] = 'Cambiar Categor&iacute;a A';
$lang['select'] = 'Seleccionar';
$lang['approve'] = 'Establecer el estado a &#039;Publicado&#039;';
$lang['revert'] = 'Establecer el estado a &#039;Borrador&#039;';
$lang['hide_summary_field'] = 'Esconder el campo resumen cuando se agrega o editan art&iacute;culos';
$lang['textbox'] = 'Entrada de Texto';
$lang['checkbox'] = 'Casilla de verificaci&oacute;n';
$lang['textarea'] = '&Aacute;rea de Texto';
$lang['file'] = 'Archivo';
$lang['auto_create_thumbnails'] = 'Crear autom&aacute;ticamente los archivos de miniaturas (thumbnails) para los archivos que tengan estas extensiones';
$lang['allowed_upload_types'] = 'Permitir que se suban s&oacute;lo los archivos con que tengan estas extensiones';
$lang['fielddefupdated'] = 'Definici&oacute;n de Campo Actualizada';
$lang['editfielddef'] = 'Editar Definici&oacute;n de Campo';
$lang['up'] = 'Arriba';
$lang['down'] = 'Abajo';
$lang['fielddefdeleted'] = 'Definici&oacute;n de Campo Eliminada';
$lang['nameexists'] = 'Ya existe un campo con ese nombre';
$lang['notanumber'] = 'La Longitud M&aacute;xima No es un N&uacute;mero';
$lang['fielddef'] = 'Definici&oacute;n de Campo';
$lang['fielddefadded'] = 'Definici&oacute;n de Campo A&ntilde;adida Correctamente';
$lang['public'] = 'P&uacute;blico';
$lang['type'] = 'Tipo';
$lang['info_maxlength'] = 'La longitud m&aacute;xima se aplica s&oacute;lo a los campos de entrada de texto.';
$lang['maxlength'] = 'Longitud M&aacute;xima';
$lang['addfielddef'] = 'A&ntilde;adir Definici&oacute;n de Campo';
$lang['customfields'] = 'Definici&oacute;nes de Campos';
$lang['deprecated'] = 'sin soporte';
$lang['subject_newnews'] = 'Se ha enviado un art&iacute;culo nuevo de Noticias';
$lang['email_subject'] = 'El Asunto del email saliente';
$lang['email_template'] = 'El formato del mensaje del email';
$lang['formsubmit_emailaddress'] = 'Direcci&oacute;n del email para recibir notificaciones de env&iacute;os de noticias';
$lang['extra'] = 'Extra ';
$lang['uploadscategory'] = 'Categor&iacute;a de Subidas';
$lang['title_available_templates'] = 'Plantillas Disponibles';
$lang['resettodefault'] = 'Resetear a los Valores Iniciales';
$lang['title_form_template'] = 'Editor de Plantilla de Formulario';
$lang['title_detail_template'] = 'Editor de Plantilla de Detalles';
$lang['title_summary_template'] = 'Editor de Plantilla de Resumen';
$lang['prompt_templatename'] = 'Nombre de Plantilla';
$lang['prompt_template'] = 'Codigo fuente de la Plantilla';
$lang['title_form_sysdefault'] = 'Plantilla de formulario por Defecto';
$lang['title_summary_sysdefault'] = 'Plantilla de Resumen por Defecto';
$lang['title_detail_sysdefault'] = 'Plantilla de Detalle por Defecto';
$lang['info_sysdefault2'] = '<strong>Nota:</strong> Esta pesta&ntilde;a contiene &aacute;reas de texto que le permitir&aacute;n editar un grupo de plantillas que son mostradas cuando crea una plantilla \&#039;nueva\&#039;  de resumen, de detalle, o de formulario.  Si cambia el contenido de esta pesta&ntilde;a, y pulsa \&#039;Enviar\&#039; <strong>no tendr&aacute; efecto sobre lo que se muestra actualmente</strong>.';
$lang['info_sysdefault'] = '<em>(el contenido usado por defecto cuando se crea una plantilla nueva)</em>';
$lang['template'] = 'Plantilla';
$lang['prompt_name'] = 'Nombre';
$lang['prompt_default'] = 'Por Defecto';
$lang['prompt_newtemplate'] = 'Crear una Nueva Plantilla';
$lang['help_pagelimit'] = 'M&aacute;ximo n&uacute;mero de elementos a mostrar (por p&aacute;gina).  Si no se proporciona este par&aacute;metro se mostraran todos los elementos coincidentes. Si se especifica, y hay m&aacute;s elementos que los especificados por este par&aacute;metro, se proporcionar&aacute;n textos y enlaces para poder navegar entre los resultados';
$lang['prompt_page'] = 'P&aacute;gina';
$lang['firstpage'] = '<<';
$lang['prevpage'] = '<';
$lang['nextpage'] = '>';
$lang['lastpage'] = '>>';
$lang['prompt_of'] = 'de';
$lang['prompt_pagelimit'] = 'L&iacute;mite de P&aacute;gina';
$lang['prompt_sorting'] = 'Ordenar por';
$lang['title_filter'] = 'Filtros';
$lang['published'] = 'Publicado';
$lang['draft'] = 'Borrador';
$lang['expired'] = 'Vencido';
$lang['author'] = 'Autor';
$lang['sysdefaults'] = 'Restaurar por defecto';
$lang['restoretodefaultsmsg'] = 'Esta operaci&oacute;n restaurar&aacute; el contenido de la plantilla a la configuraci&oacute;n original. &iquest;Est&aacute; seguro?';
$lang['addarticle'] = 'A&ntilde;adir Art&iacute;culo';
$lang['articleadded'] = 'Se ha a&ntilde;adido el art&iacute;culo correctamente.';
$lang['articleupdated'] = 'Se ha actualizado el art&iacute;culo correctamente.';
$lang['articledeleted'] = 'Se ha eliminado el art&iacute;culo correctamente.';
$lang['addcategory'] = 'A&ntilde;adir Categor&iacute;a';
$lang['categoryadded'] = 'Se ha a&ntilde;adido la categor&iacute;a correctamente.';
$lang['categoryupdated'] = 'Se ha actualizado la categor&iacute;a correctamente.';
$lang['categorydeleted'] = 'Se ha eliminado la categor&iacute;a correctamente.';
$lang['addnewsitem'] = 'A&ntilde;adir Noticia';
$lang['allcategories'] = 'Todas las Categor&iacute;as';
$lang['allentries'] = 'Todas las Entradas';
$lang['areyousure'] = '&iquest;Seguro que quiere eliminar?';
$lang['articles'] = 'Art&iacute;culos';
$lang['cancel'] = 'Cancelar';
$lang['category'] = 'Categor&iacute;a';
$lang['categories'] = 'Categor&iacute;as';
$lang['default_category'] = 'Categor&iacute;a por defecto';
$lang['content'] = 'Contenido';
$lang['dateformat'] = '%s no esta en formata yyyy-mm-dd hh:mm:ss v&aacute;lido';
$lang['delete'] = 'Borrar';
$lang['description'] = 'A&ntilde;adir, editar y borrar Noticias';
$lang['formtemplate'] = 'Plantillas de Formulario';
$lang['detailtemplate'] = 'Plantillas de Detalle';
$lang['default_templates'] = 'Plantillas por Defecto';
$lang['detailtemplateupdated'] = 'Se guard&oacute; correctamente en la base de datos la Plantilla de Detalle actualizada.';
$lang['displaytemplate'] = 'Mostrar Plantilla';
$lang['edit'] = 'Editar';
$lang['enddate'] = 'Fecha de Fin';
$lang['endrequiresstart'] = 'Una fecha de fin requiere tambi&eacute;n una fecha de inicio';
$lang['entries'] = '%s Entradas';
$lang['status'] = 'Estado';
$lang['expiry'] = 'Vencimiento';
$lang['filter'] = 'Filtro';
$lang['more'] = 'M&aacute;s';
$lang['category_label'] = 'Categor&iacute;a:';
$lang['author_label'] = 'Enviado por:';
$lang['extra_label'] = 'Extra: ';
$lang['moretext'] = 'Texto M&aacute;s';
$lang['name'] = 'Nombre';
$lang['news'] = 'Noticias';
$lang['news_return'] = 'Volver';
$lang['newcategory'] = 'Categor&iacute;a Nueva';
$lang['needpermission'] = 'Necesitas permisos de &#039;%s&#039; para realizar esta funci&oacute;n.';
$lang['nocategorygiven'] = 'No hay Categor&iacute;a';
$lang['startdatetoolate'] = 'La Fecha de Comienzo es muy tarde (&iquest;posterior a fecha final?)';
$lang['nocontentgiven'] = 'No hay Contenido';
$lang['noitemsfound'] = '<strong>Ning&uacute;n</strong> elemento encontrado en categor&iacute;a: %s';
$lang['nopostdategiven'] = 'No hay Fecha de Env&iacute;o';
$lang['note'] = '<em>Nota:</em> Las Fechas deben estar en formato &#039;yyyy-mm-dd hh:mm:ss&#039;.';
$lang['notitlegiven'] = 'No hay T&iacute;tulo';
$lang['nonamegiven'] = 'No hay Nombre';
$lang['numbertodisplay'] = 'N&uacute;mero a Mostrar (en blanco muestra todos los registros)';
$lang['print'] = 'Imprimir';
$lang['postdate'] = 'Fecha de Env&iacute;o';
$lang['postinstall'] = 'Aseg&uacute;rese de que los usuarios que vayan a administrar noticias tengan activado el permiso &quot;Modificar Noticias&quot;.';
$lang['selectcategory'] = 'Seleccionar Categor&iacute;a';
$lang['showchildcategories'] = 'Mostrar Subcategor&iacute;as';
$lang['sortascending'] = 'Orden Ascendente';
$lang['startdate'] = 'Fecha de Inicio';
$lang['startoffset'] = 'Comienza a mostrar desde el en&eacute;simo elemento';
$lang['startrequiresend'] = 'Una fecha de inicio requiere tambi&eacute;n una de fin';
$lang['apply'] = 'Aplicar';
$lang['submit'] = 'Enviar';
$lang['summary'] = 'Resumen';
$lang['summarytemplate'] = 'Plantilla de Resumen';
$lang['summarytemplateupdated'] = 'La Plantilla de Resumen de Noticias se actualiz&oacute; correctamente.';
$lang['title'] = 'T&iacute;tulo';
$lang['options'] = 'Opciones';
$lang['optionsupdated'] = 'Las opciones se actualizaron correctamente.';
$lang['useexpiration'] = 'Usar Fecha de Vencimiento';
$lang['eventdesc-NewsArticleAdded'] = 'Se env&iacute;a cuando se a&ntilde;ade un art&iacute;culo.';
$lang['eventhelp-NewsArticleAdded'] = '<p>Se env&iacute;a cuando a&ntilde;adimos un art&iacute;culo.</p>
<h4>Par&aacute;metros</h4>
<ul>
<li>\&quot;news_id\&quot; - Id del art&iacute;culo</li>
<li>\&quot;category_id\&quot; - Id de la categor&iacute;a del art&iacute;culo</li>
<li>\&quot;title\&quot; - T&iacute;tulo del art&iacute;culo</li>
<li>\&quot;content\&quot; - Contenido del art&iacute;culo</li>
<li>\&quot;summary\&quot; - Resumen del art&iacute;culo</li>
<li>\&quot;status\&quot; - estado del art&iacute;culo (&quot;borrador&quot; o &quot;publicado&quot;)</li>
<li>\&quot;start_time\&quot; - Fecha de inicio a partir de la cual se muestra el art&iacute;culo</li>
<li>\&quot;end_time\&quot; - Fecha de vencimiento a partir de la cual no se muestra el art&iacute;culo</li>
<li>\&quot;useexp\&quot; - Si la fecha de vencimiento se ignora o no</li>
</ul>
';
$lang['eventdesc-NewsArticleEdited'] = 'Se envia cuando editamos un art&iacute;culo.';
$lang['eventhelp-NewsArticleEdited'] = '<p>Se env&iacute;a cuando se edita un art&iacute;culo.</p>
<h4>Par&aacute;metros</h4>
<ul>
<li>\&quot;news_id\&quot; - Id del art&iacute;culo</li>
<li>\&quot;category_id\&quot; - Id de la categor&iacute;a del art&iacute;culo</li>
<li>\&quot;title\&quot; - T&iacute;tulo del art&iacute;culo</li>
<li>\&quot;content\&quot; - Contenido del art&iacute;culo</li>
<li>\&quot;summary\&quot; - Resumen del art&iacute;culo</li>
<li>\&quot;status\&quot; - estado del art&iacute;culo (&quot;borrador&quot; o &quot;publicado&quot;)</li>
<li>\&quot;start_time\&quot; - Fecha de inicio a partir de la cual se muestra el art&iacute;culo</li>
<li>\&quot;end_time\&quot; - Fecha de vencimiento a partir de la cual no se muestra el art&iacute;culo</li>
<li>\&quot;useexp\&quot; - Si la fecha de vencimiento se ignora o no</li>
</ul>
';
$lang['eventdesc-NewsArticleDeleted'] = 'Se env&iacute;a cuando eliminamos un art&iacute;culo.';
$lang['eventhelp-NewsArticleDeleted'] = '<p>Se env&iacute;a cuando se elimina un art&iacute;culo.</p>
<h4>Par&aacute;metros</h4>
<ul>
<li>\&quot;news_id\&quot; - Id del art&iacute;culo de noticias</li>
</ul>';
$lang['eventdesc-NewsCategoryAdded'] = 'Se env&iacute;a cuando a&ntilde;adimos una categor&iacute;a.';
$lang['eventhelp-NewsCategoryAdded'] = '<p>Se env&iacute;a cuando se a&ntilde;ade una categor&iacute;a.</p>
<h4>Par&aacute;metros</h4>
<ul>
<li>\&quot;category_id\&quot; - Id de la categor&iacute;a del art&iacute;culo</li>
<li>\&quot;name\&quot; - Nombre de la categor&iacute;a</li>
</ul>';
$lang['eventdesc-NewsCategoryEdited'] = 'Se envia cuando editamos una categor&iacute;a.';
$lang['eventhelp-NewsCategoryEdited'] = '<p>Se env&iacute;a cuando se edita una categor&iacute;a.</p>
<h4>Par&aacute;metros</h4>
<ul>
<li>\&quot;category_id\&quot; - Id de la categor&iacute;a de noticias</li>
<li>\&quot;name\&quot; - Nombre de la categor&iacute;a de noticias</li>
<li>\&quot;origname\&quot; - El nombre original de la categor&iacute;a de noticias</li>
</ul>';
$lang['eventdesc-NewsCategoryDeleted'] = 'Se env&iacute;a cuando eliminamos una categor&iacute;a.';
$lang['eventhelp-NewsCategoryDeleted'] = '<p>Se env&iacute;a cuando se elimina una categor&iacute;a.</p>
<h4>Par&aacute;metros</h4>
<ul>
<li>\&quot;category_id\&quot; - Id de la categor&iacute;a eliminada</li>
<li>\&quot;name\&quot; - Nombre de la categor&iacute;a eliminada</li>
</ul>
';
$lang['help_articleid'] = 'Este parametro s&oacute;lo se aplica a la vista en detalle. Permite especificar qu&eacute; art&iacute;culos de noticias se muestran en el modo detalle. Con el valor especial -1, el sistema mostrar&aacute; el articulo m&aacute;s nuevo, publicado, que no ha vencido.';
$lang['helpnumber'] = 'N&uacute;mero m&aacute;ximo de elementos a mostrar (por p&aacute;gina) -- dej&aacute;ndolo en blanco los muestra todos. Es equivalente al par&aacute;metro pagelimit.';
$lang['helpstart'] = 'Comenzar por el en&eacute;simo elemento -- dej&aacute;ndolo en blanco comenzar&aacute; por el primero.';
$lang['helpcategory'] = 'Se usa en la vista de resumen para mostrar s&oacute;lo los elementos de las categor&iacute;as especificadas. <b>Usar * despu&eacute;s del nombre para mostrar sub-categor&iacute;as.</b>  Se pueden usar m&uacute;ltiples categor&iacute;as separ&aacute;ndolas por una coma. Si se deja en blanco muestra todas las categor&iacute;as. Este par&aacute;metro tambi&eacute;n funciona para la acci&oacute;n de env&iacute;o a trav&eacute;s del portal, pero s&oacute;lo soporta un nombre de categor&iacute;a.';
$lang['helpmoretext'] = 'Texto a mostrar al final de una noticia si esta supera la longitud del resumen.  Por defecto es &quot;M&aacute;s&quot;';
$lang['helpsummarytemplate'] = 'Use una plantilla de base de datos distinta para mostrar el resumen del art&iacute;culo.  Esta plantilla debe existir y estar visible en la pesta&ntilde;a de la plantilla de resumen en la administraci&oacute;n de Noticias, aunque no tiene porqu&eacute; ser la plantilla por defecto. Si este par&aacute;metro no se especifica, entonces se usar&aacute; a la plantilla actualmente marcada por defecto.';
$lang['helpformtemplate'] = 'Use una plantilla de la base de datos para mostrar el formulario de env&iacute;o del art&iacute;culo. Esta plantilla debe existir y estar visible en la pesta&ntilde;a de plantillas de formulario en la administraci&oacute;n de Noticias, aunque no tiene porqu&eacute; ser la plantilla por defecto. Si este par&aacute;metro no se especifica, entonces se usar&aacute; a la plantilla actualmente marcada por defecto.';
$lang['helpbrowsecattemplate'] = 'Use una plantilla de base de datos para mostrar el explorador de categor&iacute;as.  Esta plantilla debe existir y estar visible en la pesta&ntilde;a de Plantillas de Exploraci&oacute;n de Categor&iacute;as en la administraci&oacute;n de Noticias, aunque no tiene porqu&eacute; ser la plantilla por defecto. Si este par&aacute;metro no se especifica, entonces se usar&aacute; a la plantilla actualmente marcada por defecto.';
$lang['helpdetailtemplate'] = 'Use una plantilla de base de datos distinta para mostrar el art&iacute;culo en detalle. Esta plantilla debe existir y estar visible en la pesta&ntilde;a de plantilla de detalles en la administraci&oacute;n de Noticias, aunque no tiene porqu&eacute; ser la plantilla por defecto.  Si este par&aacute;metro no se especifica, entonces se usar&aacute; a la plantilla actualmente marcada por defecto.';
$lang['helpsortby'] = 'Campo por el que ordenar.  Las opciones son: &quot;news_date&quot;, &quot;summary&quot;, &quot;news_data&quot;, &quot;news_category&quot;, &quot;news_title&quot;, &quot;random&quot;.  Por  defecto es &quot;news_date&quot;. Si se especifica &quot;random&quot;, el par&aacute;metro sortasc se ignora.';
$lang['helpsortasc'] = 'Ordenar noticias por fechas en orden ascendente en lugar de descendente.';
$lang['helpdetailpage'] = 'P&aacute;gina donde se muestra la noticia en detalle.  Puede ser un alias de p&aacute;gina o un id. Se usa para permitir que los detalles se muestren en una plantilla diferente de la de resumen.';
$lang['helpshowarchive'] = 'Mostrar s&oacute;lo los art&iacute;culos de noticias vencidos.';
$lang['helpbrowsecat'] = 'Muestra un listado de categor&iacute;as que se puede examinar.';
$lang['helpaction'] = 'Sobrescribe la acci&oacute;n por defecto. Los valores posibles son:
<ul>
<li>&quot;detai&quot; - para mostrar un articleid espec&iacute;fico en el modo de detalle.</li>
<li>&quot;default&quot; - para mostrar la vista de resumen</li>
<li>&quot;fesubmit&quot; - para mostrar el formulario en el portal de forma que permita a los usuarios eviar art&iacute;culos de noticias directamentes desde el portal.</li>
<li>&quot;browsecat&quot; - para mostrar una lista de categor&iacute;as en forma de enlaces.</li>
</ul>';
$lang['help'] = '<h3>Notas Importantes</h3>
<p>A partir de la versi&oacute;n 2.9 de las News se ha eliminado el miembro formatpostdate de las plantillas, as&iacute; como el par&aacute;metro dateformat. Debe usar el modificador cms_date_format (como se indica en las plantillas por defecto) para formatear las fechas, y usar en las plantillas entry->postdate en vez de entry->formatpostdate.</p>
<h3>&iquest;Qu&eacute; hace esto?</h3>
<p>News es un m&oacute;dulo para mostrar noticias de acontecimientos en su p&aacute;gina, similar al estilo de un blog, pero con m&aacute;s posibilidades.  Cuando se instala el m&oacute;dulo, se agrega una p&aacute;gina de Administraci&oacute;n de Noticias al men&uacute; de administraci&oacute;n que le permitir&aacute; seleccionar o crear una categor&iacute;a de noticias.  Una vez que se crea o se selecciona una categor&iacute;a de noticias, se muestra una lista de nuevos &iacute;tems para esa categor&iacute;a.  A partir de aqu&iacute; puede agregar, editar o eliminar items de esa categor&iacute;a.</p>
<h4>Varios m&eacute;todos de visualizaci&oacute;n</h4>
<p>Debido a la cantidad de par&aacute;metros soportados por el m&oacute;dulo de noticias, as&iacute; como la cantidad de plantillas que puede elegir, las opciones de visualizaci&oacute;n de los art&iacute;culos de noticias son ilimitadas.</p>
<h4>Campos Personalizados</h4>
<p>El m&oacute;dulo de noticias permite definir numerosos campos personalizados (incluyendo archivos e im&aacute;genes) lo que le permitir&aacute; incluir archivos pdf o numerosas im&aacute;genes en los art&iacute;culos.</p>
<h4>Categor&iacute;as</h4>
<p>News proporciona un mecanismos de categor&iacute;as en jerarqu&iacute;a para organizar los art&iacute;culos. Un art&iacute;culo de noticias s&oacute;lo puede estar en una posici&oacute;n de esta jerarqu&iacute;a.</p>
<h4>Vencimiento y Estado</h4>
<p>Cada art&iacute;culo de noticias puede tener una fecha de vencimiento opcional, a partir de la cual no se mostrar&aacute; en la p&aacute;gina web. Tambi&eacute;n, los art&iacute;culos se pueden marcar como <em>borrador</em> para retirarlos permanentemente de la p&aacute;gina web.</p>
<h3>Seguridad</h3>
	<p>El usuario debe pertenecer a un grupo con el permiso &#039;Modificar Noticias&#039; para poder a&ntilde;adir o editar entradas de noticias.</p>
<p>Tambi&eacute;n, para poder eliminar entradas de noticias, el usuario debe pertenecer a un grupo con el permiso &#039;Eliminar Art&iacute;culos de Noticias&#039;.</p>
	<p>Para poder editar los dise&ntilde;os de las plantillas, el usuario debe pertenecer a un grupo con el permiso &#039;Modificar Plantillas&#039;.</p>
	<p>Para poder editar las preferencias globales de las noticias, el usuario debe pertenecer a un grupo con el permiso &#039;Modificar las Preferencias del Sitio&#039;.</p>
	<p>Adem&aacute;s, para aprobar noticias que ser&aacute;n mostradas en el portal, el usuario deb pertenecer a un grupo con el permiso &#039;Aprobar Noticias&#039;.</p>
	<h3>&iquest;Como lo uso?</h3>
	<p>La forma m&aacute;s sencilla de utilizarlo es mediante la etiqueta de envoltura {news} (envuelve al m&oacute;dulo en una etiqueta, para simplificar la sintaxis).  Esto inserta el m&oacute;dulo en cualquier lugar que desee de la plantilla o de la p&aacute;gina, y muestra los &iacute;tems de noticias.  El c&oacute;digo tendr&aacute; la forma: <code>{news number=&#039;5&#039;}</code></p>
<h3>Plantillas</h3>
	<p>Desde la versi&oacute;n 2.3 News soporta m&uacute;ltiples plantillas de base de datos, dejando de soportar las plantillas de archivo.  Los usuarios que usaban el viejo sistema de plantillas de archivo deber&aacute;n seguir estos pasos (para cada plantilla):
<ul>
<li>Copiar el texto de la plantilla de archivo en el portapapeles</li>
<li>Crear una nueva plantilla de base de datos <em>(tanto la de resumen como la de detalles, seg&uacute;n se necesite)</em>.  D&eacute; a la nueva plantilla el mismo nombre (incluyendo la extensi&oacute;n .tpl) que ten&iacute;a la vieja plantilla de archivo, y pegue el contenido del portapapeles.</li>
<li>Pulse en Enviar</li>
</ul>
<p>Con estos pasos se deber&iacute;a solucionar el problema de las plantillas no encontradas y otros errores smarty similares que se producen cuando actualiza a una la versi&oacute;n de CMS que incluye el m&oacute;dulo News 2.3 o superior.</p>';
$lang['utma'] = '156861353.1603343530.1339275764.1339275764.1339275764.1';
$lang['utmz'] = '156861353.1339275764.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>